@@ -124,6 +124,11 @@ new IotToLambdaToDynamoDB(this, "test-iot-lambda-dynamodb-stack", new IotToLambd
 |iotTopicRuleProps|[`iot.CfnTopicRuleProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_iot.CfnTopicRuleProps.html)|User provided props to override the default props|
 |dynamoTableProps?|[`dynamodb.TableProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_dynamodb.TableProps.html)|Optional user provided props to override the default props for DynamoDB Table|
 |tablePermissions?|`string`|Optional table permissions to grant to the Lambda function. One of the following may be specified: `All`, `Read`, `ReadWrite`, `Write`.|
+|existingTableObj?|[`dynamodb.Table`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_dynamodb.Table.html)|Existing instance of DynamoDB table object, providing both this and `dynamoTableProps` will cause an error.|
+|tableEnvironmentVariableName?|`string`|Optional Name for the Lambda function environment variable set to the name of the DynamoDB table. Default: DDB_TABLE_NAME |
+|existingVpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.IVpc.html)|An optional, existing VPC into which this pattern should be deployed. When deployed in a VPC, the Lambda function will use ENIs in the VPC to access network resources and a Gateway Endpoint will be created in the VPC for Amazon DynamoDB. If an existing VPC is provided, the `deployVpc` property cannot be `true`. This uses `ec2.IVpc` to allow clients to supply VPCs that exist outside the stack using the [`ec2.Vpc.fromLookup()`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.Vpc.html#static-fromwbrlookupscope-id-options) method.|
+|vpcProps?|[`ec2.VpcProps`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.VpcProps.html)|Optional user-provided properties to override the default properties for the new VPC. `enableDnsHostnames`, `enableDnsSupport`, `natGateways` and `subnetConfiguration` are set by the pattern, so any values for those properties supplied here will be overrriden. If `deployVpc` is not `true` then this property will be ignored.|
+|deployVpc?|`boolean`|Whether to create a new VPC based on `vpcProps` into which to deploy this pattern. Setting this to true will deploy the minimal, most private VPC to run the pattern:<ul><li> One isolated subnet in each Availability Zone used by the CDK program</li><li>`enableDnsHostnames` and `enableDnsSupport` will both be set to true</li></ul>If this property is `true` then `existingVpc` cannot be specified. Defaults to `false`.|
 
 ## Pattern Properties
 
@@ -132,6 +137,7 @@ new IotToLambdaToDynamoDB(this, "test-iot-lambda-dynamodb-stack", new IotToLambd
 |iotTopicRule|[`iot.CfnTopicRule`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_iot.CfnTopicRule.html)|Returns an instance of iot.CfnTopicRule created by the construct|
 |lambdaFunction|[`lambda.Function`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_lambda.Function.html)|Returns an instance of lambda.Function created by the construct|
 |dynamoTable|[`dynamodb.Table`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_dynamodb.Table.html)|Returns an instance of dynamodb.Table created by the construct|
+|vpc?|[`ec2.IVpc`](https://docs.aws.amazon.com/cdk/api/v2/docs/aws-cdk-lib.aws_ec2.IVpc.html)|Returns an interface on the VPC used by the pattern (if any). This may be a VPC created by the pattern or the VPC supplied to the pattern constructor.|
 
 ## Default settings
 
@@ -182,6 +188,7 @@ from typeguard import check_type
 from ._jsii import *
 
 import aws_cdk.aws_dynamodb as _aws_cdk_aws_dynamodb_ceddda9d
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
 import aws_cdk.aws_iot as _aws_cdk_aws_iot_ceddda9d
 import aws_cdk.aws_lambda as _aws_cdk_aws_lambda_ceddda9d
 import constructs as _constructs_77d1e7e8
@@ -198,19 +205,27 @@ class IotToLambdaToDynamoDB(
         id: builtins.str,
         *,
         iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+        deploy_vpc: typing.Optional[builtins.bool] = None,
         dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        table_environment_variable_name: typing.Optional[builtins.str] = None,
         table_permissions: typing.Optional[builtins.str] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: - represents the scope for all the resources.
         :param id: - this is a a scope-unique id.
         :param iot_topic_rule_props: User provided props to override the default props. Default: - Default props are used
+        :param deploy_vpc: Whether to deploy a new VPC. Default: - false
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
+        :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
+        :param table_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the DynamoDB table. Default: - DDB_TABLE_NAME
         :param table_permissions: Optional table permissions to grant to the Lambda function. One of the following may be specified: "All", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
+        :param vpc_props: Properties to override default properties if deployVpc is true.
 
         :access: public
         :since: 0.8.0
@@ -222,10 +237,14 @@ class IotToLambdaToDynamoDB(
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToLambdaToDynamoDBProps(
             iot_topic_rule_props=iot_topic_rule_props,
+            deploy_vpc=deploy_vpc,
             dynamo_table_props=dynamo_table_props,
             existing_lambda_obj=existing_lambda_obj,
+            existing_vpc=existing_vpc,
             lambda_function_props=lambda_function_props,
+            table_environment_variable_name=table_environment_variable_name,
             table_permissions=table_permissions,
+            vpc_props=vpc_props,
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
@@ -245,16 +264,25 @@ class IotToLambdaToDynamoDB(
     def lambda_function(self) -> _aws_cdk_aws_lambda_ceddda9d.Function:
         return typing.cast(_aws_cdk_aws_lambda_ceddda9d.Function, jsii.get(self, "lambdaFunction"))
 
+    @builtins.property
+    @jsii.member(jsii_name="vpc")
+    def vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], jsii.get(self, "vpc"))
+
 
 @jsii.data_type(
     jsii_type="@aws-solutions-constructs/aws-iot-lambda-dynamodb.IotToLambdaToDynamoDBProps",
     jsii_struct_bases=[],
     name_mapping={
         "iot_topic_rule_props": "iotTopicRuleProps",
+        "deploy_vpc": "deployVpc",
         "dynamo_table_props": "dynamoTableProps",
         "existing_lambda_obj": "existingLambdaObj",
+        "existing_vpc": "existingVpc",
         "lambda_function_props": "lambdaFunctionProps",
+        "table_environment_variable_name": "tableEnvironmentVariableName",
         "table_permissions": "tablePermissions",
+        "vpc_props": "vpcProps",
     },
 )
 class IotToLambdaToDynamoDBProps:
@@ -262,17 +290,25 @@ class IotToLambdaToDynamoDBProps:
         self,
         *,
         iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+        deploy_vpc: typing.Optional[builtins.bool] = None,
         dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        table_environment_variable_name: typing.Optional[builtins.str] = None,
         table_permissions: typing.Optional[builtins.str] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param iot_topic_rule_props: User provided props to override the default props. Default: - Default props are used
+        :param deploy_vpc: Whether to deploy a new VPC. Default: - false
         :param dynamo_table_props: Optional user provided props to override the default props. Default: - Default props are used
         :param existing_lambda_obj: Existing instance of Lambda Function object, providing both this and ``lambdaFunctionProps`` will cause an error. Default: - None
+        :param existing_vpc: An existing VPC for the construct to use (construct will NOT create a new VPC in this case).
         :param lambda_function_props: User provided props to override the default props for the Lambda function. Default: - Default props are used
+        :param table_environment_variable_name: Optional Name for the Lambda function environment variable set to the name of the DynamoDB table. Default: - DDB_TABLE_NAME
         :param table_permissions: Optional table permissions to grant to the Lambda function. One of the following may be specified: "All", "Read", "ReadWrite", "Write". Default: - Read/write access is given to the Lambda function if no value is specified.
+        :param vpc_props: Properties to override default properties if deployVpc is true.
 
         :summary: The properties for the IotToLambdaToDynamoDB class.
         '''
@@ -282,24 +318,38 @@ class IotToLambdaToDynamoDBProps:
             dynamo_table_props = _aws_cdk_aws_dynamodb_ceddda9d.TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = _aws_cdk_aws_lambda_ceddda9d.FunctionProps(**lambda_function_props)
+        if isinstance(vpc_props, dict):
+            vpc_props = _aws_cdk_aws_ec2_ceddda9d.VpcProps(**vpc_props)
         if __debug__:
             type_hints = typing.get_type_hints(_typecheckingstub__4abf9105fca6670b5209365799827a59d704a6a776881efc469c3d278696635f)
             check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
+            check_type(argname="argument deploy_vpc", value=deploy_vpc, expected_type=type_hints["deploy_vpc"])
             check_type(argname="argument dynamo_table_props", value=dynamo_table_props, expected_type=type_hints["dynamo_table_props"])
             check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument existing_vpc", value=existing_vpc, expected_type=type_hints["existing_vpc"])
             check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument table_environment_variable_name", value=table_environment_variable_name, expected_type=type_hints["table_environment_variable_name"])
             check_type(argname="argument table_permissions", value=table_permissions, expected_type=type_hints["table_permissions"])
+            check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
         self._values: typing.Dict[builtins.str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
+        if deploy_vpc is not None:
+            self._values["deploy_vpc"] = deploy_vpc
         if dynamo_table_props is not None:
             self._values["dynamo_table_props"] = dynamo_table_props
         if existing_lambda_obj is not None:
             self._values["existing_lambda_obj"] = existing_lambda_obj
+        if existing_vpc is not None:
+            self._values["existing_vpc"] = existing_vpc
         if lambda_function_props is not None:
             self._values["lambda_function_props"] = lambda_function_props
+        if table_environment_variable_name is not None:
+            self._values["table_environment_variable_name"] = table_environment_variable_name
         if table_permissions is not None:
             self._values["table_permissions"] = table_permissions
+        if vpc_props is not None:
+            self._values["vpc_props"] = vpc_props
 
     @builtins.property
     def iot_topic_rule_props(self) -> _aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps:
@@ -311,6 +361,15 @@ class IotToLambdaToDynamoDBProps:
         assert result is not None, "Required property 'iot_topic_rule_props' is missing"
         return typing.cast(_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, result)
 
+    @builtins.property
+    def deploy_vpc(self) -> typing.Optional[builtins.bool]:
+        '''Whether to deploy a new VPC.
+
+        :default: - false
+        '''
+        result = self._values.get("deploy_vpc")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def dynamo_table_props(
         self,
@@ -333,6 +392,12 @@ class IotToLambdaToDynamoDBProps:
         result = self._values.get("existing_lambda_obj")
         return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function], result)
 
+    @builtins.property
+    def existing_vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
+        '''An existing VPC for the construct to use (construct will NOT create a new VPC in this case).'''
+        result = self._values.get("existing_vpc")
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
+
     @builtins.property
     def lambda_function_props(
         self,
@@ -344,6 +409,15 @@ class IotToLambdaToDynamoDBProps:
         result = self._values.get("lambda_function_props")
         return typing.cast(typing.Optional[_aws_cdk_aws_lambda_ceddda9d.FunctionProps], result)
 
+    @builtins.property
+    def table_environment_variable_name(self) -> typing.Optional[builtins.str]:
+        '''Optional Name for the Lambda function environment variable set to the name of the DynamoDB table.
+
+        :default: - DDB_TABLE_NAME
+        '''
+        result = self._values.get("table_environment_variable_name")
+        return typing.cast(typing.Optional[builtins.str], result)
+
     @builtins.property
     def table_permissions(self) -> typing.Optional[builtins.str]:
         '''Optional table permissions to grant to the Lambda function.
@@ -355,6 +429,12 @@ class IotToLambdaToDynamoDBProps:
         result = self._values.get("table_permissions")
         return typing.cast(typing.Optional[builtins.str], result)
 
+    @builtins.property
+    def vpc_props(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps]:
+        '''Properties to override default properties if deployVpc is true.'''
+        result = self._values.get("vpc_props")
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
@@ -379,10 +459,14 @@ def _typecheckingstub__59c8611af9fdcb1ce543f81724c06e8bc8cc0e01d77f48a7f6976e0e9
     id: builtins.str,
     *,
     iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+    deploy_vpc: typing.Optional[builtins.bool] = None,
     dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
     existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
     lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    table_environment_variable_name: typing.Optional[builtins.str] = None,
     table_permissions: typing.Optional[builtins.str] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
 ) -> None:
     """Type checking stubs"""
     pass
@@ -390,10 +474,14 @@ def _typecheckingstub__59c8611af9fdcb1ce543f81724c06e8bc8cc0e01d77f48a7f6976e0e9
 def _typecheckingstub__4abf9105fca6670b5209365799827a59d704a6a776881efc469c3d278696635f(
     *,
     iot_topic_rule_props: typing.Union[_aws_cdk_aws_iot_ceddda9d.CfnTopicRuleProps, typing.Dict[builtins.str, typing.Any]],
+    deploy_vpc: typing.Optional[builtins.bool] = None,
     dynamo_table_props: typing.Optional[typing.Union[_aws_cdk_aws_dynamodb_ceddda9d.TableProps, typing.Dict[builtins.str, typing.Any]]] = None,
     existing_lambda_obj: typing.Optional[_aws_cdk_aws_lambda_ceddda9d.Function] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
     lambda_function_props: typing.Optional[typing.Union[_aws_cdk_aws_lambda_ceddda9d.FunctionProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    table_environment_variable_name: typing.Optional[builtins.str] = None,
     table_permissions: typing.Optional[builtins.str] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
 ) -> None:
     """Type checking stubs"""
     pass
